SyncComponent

Trait SyncComponent 

pub trait SyncComponent {
    // Required methods
    fn sync_component<T: Component + TypePath + DynamicTypePath + Reflect + FromReflect + GetTypeRegistration + Clone>(
        &mut self,
    ) -> &mut Self;
    fn sync_materials(&mut self, enable: bool);
    fn sync_meshes(&mut self, enable: bool);
    fn sync_audios(&mut self, enable: bool);
}
Use this trait extension to configure sync details for your app. Every component that needs to be synched must be called with sync_component. To enable assets synching, use the other sync_* methods. By default nothing is being synched, so you’ll need to additively call all these.

Required Methods

fn sync_component<T: Component + TypePath + DynamicTypePath + Reflect + FromReflect + GetTypeRegistration + Clone>( &mut self, ) -> &mut Self

fn sync_materials(&mut self, enable: bool)

fn sync_meshes(&mut self, enable: bool)

fn sync_audios(&mut self, enable: bool)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SyncComponent for App

Source

fn sync_component<T>(&mut self) -> &mut Self

Source

fn sync_materials(&mut self, enable: bool)

Source

fn sync_meshes(&mut self, enable: bool)

Source

fn sync_audios(&mut self, enable: bool)

Implementors